pygeodesy.karney.Caps

Package pygeodesy :: Module karney :: Class Caps |
[frames] | no frames]

# Class Caps

    object --+
             |
            Caps

Enum-style masks to be bit-`or`'ed to specify `geodesic`, `rhumb` or `-lines` capabilities (`caps`) and method results (`outmask`).

`AREA` - compute the area `S12`,

`AZIMUTH` - include azimuths `azi1` and `azi2`,

`DISTANCE` - compute distance `s12` and angular distance `a12`,

`DISTANCE_IN` - allow distance `s12` in method `.Direct`,

`EMPTY` - nothing, formerly aka `NONE`,

`GEODESICSCALE` - compute geodesic scales `M12` and `M21`,

`LATITUDE` - compute latitude `lat2`,

`LINE_OFF` - Line without updates from parent `geodesic` or `rhumb`.

`LONGITUDE` - compute longitude `lon2`,

`LONG_UNROLL` - unroll `lon2` in method `.Direct`,

`NONFINITONAN` - set all `GDict` items to `NAN` iff any argument is `non-finite`.

`REDUCEDLENGTH` - compute the reduced length `m12`,

`REVERSE2` - reverse azimuth `azi2` by 180 degrees,

and `ALL` - all of the above.

`STANDARD` = `AZIMUTH | DISTANCE | LATITUDE | LONGITUDE`

`LINE_CAPS` = `STANDARD | DISTANCE_IN | REDUCEDLENGTH | GEODESICSCALE`

Instance Methods
items(self) Yield all public `Caps` as 2-tuple `(NAME, mask)`. |
toStr(self, Cask, sep='|') Return `Caps` or an `outmask` as `str` or tuple of `str`s. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| ALL = `32671`
| AREA = `16400`
| AZIMUTH = `512`
| AZIMUTH_DISTANCE = `1537`
| AZIMUTH_DISTANCE_AREA = `17937`
| DISTANCE = `1025`
| DISTANCE_IN = `2051`
| EMPTY = `0` hash(x)
| GEODESICSCALE = `8197`
| LATITUDE = `128`
| LATITUDE_LONGITUDE = `392`
| LATITUDE_LONGITUDE_AREA = `16792`
| LINE_CAPS = `16271`
| LINE_OFF = `65536`
| LONGITUDE = `264`
| LONG_UNROLL = `32768`
| NONFINITONAN = `131072`
| REDUCEDLENGTH = `4101`
| REVERSE2 = `262144`
| STANDARD = `1929`
| STANDARD_LINE = `3979`

Properties
Inherited from `object`: `__class__`